gegl r2954 - in trunk: . tests



Author: martinn
Date: Sun Mar  1 10:08:15 2009
New Revision: 2954
URL: http://svn.gnome.org/viewvc/gegl?rev=2954&view=rev

Log:
Perform a third test processing without any changes at all

Perform a third test processing without any changes at all since this
is a better way to stress test caching mechanisms.

Modified:
   trunk/ChangeLog
   trunk/tests/test-proxynop-processing.c

Modified: trunk/tests/test-proxynop-processing.c
==============================================================================
--- trunk/tests/test-proxynop-processing.c	(original)
+++ trunk/tests/test-proxynop-processing.c	Sun Mar  1 10:08:15 2009
@@ -83,8 +83,8 @@
       goto abort;
     }
 
   /* Process the graph AGAIN and make sure we get the expected result
    * as this puts some stress on the caching mechanisms
    */
   gegl_node_set (color_in_graph,
                  "value", color2,
@@ -105,7 +105,31 @@
   else
     {
       result = FAILURE;
-      g_printerr ("Second processing failed, looks like you messed up caching. Fix!");
+      g_printerr ("Second processing failed, i.e. changing color didn't work properly");
+      goto abort;
+    }
+
+  /* Process the graph again but without changing anything since this
+   * puts some stress on the caching mechanisms
+   */
+  memset (result_buffer, 0, sizeof (result_buffer));
+  gegl_node_blit (graph_output_proxy,
+                  1.0,
+                  &roi,
+                  babl_format ("RGB u8"),
+                  result_buffer,
+                  GEGL_AUTO_ROWSTRIDE,
+                  GEGL_BLIT_DEFAULT);
+  if (result_buffer[RED]   == 0   &&
+      result_buffer[GREEN] == 0   &&
+      result_buffer[BLUE]  == 255)
+    {
+      result = SUCCESS;
+    }
+  else
+    {
+      result = FAILURE;
+      g_printerr ("Third processing failed, looks like you messed up caching");
       goto abort;
     }
 
@@ -83,8 +83,8 @@
     }
 
-  /* Process the graph AGAIN and make sure we get the expected result
-   * as this puts some stress on the caching mechanisms
+  /* Process the graph again with a different color and make sure we
+   * get the expected result
    */
   gegl_node_set (color_in_graph,



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]